=========
audobject
=========

|tests| |coverage| |docs| |python-versions| |license|

Generic interface for serializing objects to yaml_.

Have a look at the installation_ and usage_ instructions.

.. _yaml: https://yaml.org/
.. _installation: https://audeering.github.io/audobject/install.html
.. _usage: https://audeering.github.io/audobject/usage.html


.. badges images and links:
.. |tests| image:: https://github.com/audeering/audobject/workflows/Test/badge.svg
    :target: https://github.com/audeering/audobject/actions?query=workflow%3ATest
    :alt: Test status
.. |coverage| image:: https://codecov.io/gh/audeering/audobject/branch/master/graph/badge.svg?token=7S4Y766FC7
    :target: https://codecov.io/gh/audeering/audobject/
    :alt: code coverage
.. |docs| image:: https://img.shields.io/pypi/v/audobject?label=docs
    :target: https://audeering.github.io/audobject/
    :alt: audobject's documentation
.. |license| image:: https://img.shields.io/badge/license-MIT-green.svg
    :target: https://github.com/audeering/audfactory/blob/master/LICENSE
    :alt: audfactory's MIT license
.. |python-versions| image:: https://img.shields.io/pypi/pyversions/audobject.svg
    :target: https://pypi.org/project/audobject/
    :alt: audobjects's supported Python versions
